@@ -19,11 +19,11 @@
 
 
 
-
+from faker import Faker
 
 from utils.object_utils import rand_option as option
 from utils.string_generation import text,phone,email,url,abstract_name,rand
-
+fake = Faker()
 
 
 
